@@ -3,7 +3,7 @@ package MaxMind::DB::Writer;
 use strict;
 use warnings;
 
-our $VERSION = '0.100004';
+our $VERSION = '0.100005';
 
 1;
 
@@ -19,7 +19,7 @@ MaxMind::DB::Writer - Create MaxMind DB database files
 
 =head1 VERSION
 
-version 0.100004
+version 0.100005
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ version 0.100004
     );
 
     my $network
-        = Net::Works::Network->new_from_string( string => '8.23.0.0/16' );
+        = Net::Works::Network->new_from_string( string => '2001:db8::/48' );
 
     $tree->insert_network(
         $network,
@@ -53,7 +53,7 @@ version 0.100004
         },
     );
 
-    open my $fh, '>:bytes', '/path/to/my-ip-data.mmdb';
+    open my $fh, '>:raw', '/path/to/my-ip-data.mmdb';
     $tree->write_tree($fh);
 
 =head1 DESCRIPTION
@@ -62,6 +62,13 @@ This distribution contains the code necessary to write L<MaxMind DB database
 files|http://maxmind.github.io/MaxMind-DB/>. See L<MaxMind::DB::Writer::Tree>
 for API docs.
 
+=head1 MAC OS X SUPPORT
+
+If you're running into install errors under Mac OS X, you may need to force a
+build of the 64 bit binary. For example, if you're installing via C<cpanm>:
+
+    ARCHFLAGS="-arch x86_64" cpanm MaxMind::DB::Writer
+
 =head1 WINDOWS SUPPORT
 
 This distribution does not currently work on Windows. Reasonable patches for
@@ -99,12 +106,22 @@ Mark Fowler <mfowler@maxmind.com>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Florian Ragwitz
+=for stopwords Florian Ragwitz Jan Bieron
+
+=over 4
+
+=item *
 
 Florian Ragwitz <rafl@debian.org>
 
+=item *
+
+Jan Bieron <jbieron+github@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by MaxMind, Inc..
