@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie;
 
-our $VERSION = '0.100004';
+our $VERSION = '0.100005';
 
 use IO::Handle;
 use Math::Int64 0.51;
@@ -140,6 +140,7 @@ sub insert_network {
     my $self    = shift;
     my $network = shift;
     my $data    = shift;
+    my $additional_args = shift // {};
 
     if ( $network->version() != $self->ip_version() ) {
         my $description = $network->as_string();
@@ -155,6 +156,7 @@ sub insert_network {
         $network->prefix_length(),
         key_for_data($data),
         $data,
+        $additional_args->{force_overwrite},
     );
 
     return;
@@ -329,23 +331,30 @@ MaxMind::DB::Writer::Tree - Tree representing a MaxMind DB database in memory -
 
 =head1 VERSION
 
-version 0.100004
+version 0.100005
 
 =head1 SYNOPSIS
 
     use MaxMind::DB::Writer::Tree;
     use Net::Works::Network;
 
+    my %types = (
+        color => 'utf8_string',
+        dogs  => [ 'array', 'utf8_string' ],
+        size  => 'uint16',
+    );
+
     my $tree = MaxMind::DB::Writer::Tree->new(
-        ip_version    => 6,
-        record_size   => 24,
-        database_type => 'My-IP-Data',
-        languages     => ['en'],
-        description   => { en => 'My database of IP data' },
+        ip_version            => 6,
+        record_size           => 24,
+        database_type         => 'My-IP-Data',
+        languages             => ['en'],
+        description           => { en => 'My database of IP data' },
+        map_key_type_callback => sub { $types{ $_[0] } },
     );
 
     my $network
-        = Net::Works::Network->new_from_string( string => '8.23.0.0/16' );
+        = Net::Works::Network->new_from_string( string => '2001:db8::/48' );
 
     $tree->insert_network(
         $network,
@@ -406,13 +415,13 @@ This parameter is optional.
 
 =item * description
 
-This is hashref where the keys are language names and the values are
+This is a hashref where the keys are language names and the values are
 descriptions of the database in that language. For example, you might have
 something like:
 
     {
         en => 'My IP data',
-        fr => 'Mon Data de IP',
+        fr => q{Mon Data d'IP},
     }
 
 This parameter is required.
@@ -462,7 +471,7 @@ This parameter is optional. It defaults to false.
 
 =back
 
-=head2 $tree->insert_network( $network, $data )
+=head2 $tree->insert_network( $network, $data, $additional_args )
 
 This method expects two parameters. The first is a L<Net::Works::Network>
 object. The second can be any Perl data structure (except a coderef, glob, or
@@ -474,6 +483,12 @@ anything that can be encoded in JSON can be stored in an MMDB file. It can
 also handle unsigned 64-bit and 128-bit integers if they are passed as
 L<Math::UInt128|Math::Int128> objects.
 
+C<$additional_args> is a hash reference containing additional arguments that
+change the behavior of the insert. Currently, the only supported argument is
+C<force_overwrite>. This causes the object-wide C<merge_record_collisions>
+setting to be ignored for the insert, causing C<$data> to overwrite any
+existing data for the network.
+
 =head3 Insert Order, Merging, and Overwriting
 
 Depending on whether or not you set C<merge_record_collisions> to true in the
@@ -493,7 +508,8 @@ you need to sort your input by network prefix length.
 When C<merge_record_collisions> is I<true>, then regardless of insert order,
 the C<1.2.3.255/32> network will end up with its data plus the data provided
 for the C<1.2.3.0/24> network, while C<1.2.3.0 - 1.2.3.254> will have the
-expected data.
+expected data. This can be disabled on a per-insert basis by using the
+C<force_overwrite> argument when inserting a network as discussed above.
 
 =head2 $tree->write_tree($fh)
 
