@@ -3,7 +3,7 @@ package MaxMind::DB::Writer::Tree::Processor::VisualizeTree;
 use strict;
 use warnings;
 
-our $VERSION = '0.100004';
+our $VERSION = '0.100005';
 
 use Data::Dumper::Concise;
 use Digest::MD5 qw( md5_hex );
@@ -94,11 +94,13 @@ sub _label_for_node {
 
     my $network = $self->_network( $ip_num, $prefix_length );
 
-    return $self->_labels()->{$node_num} //=
-          "Node $node_num - "
-        . $network->as_string() . ' ('
-        . $network->first()->as_string . ' - '
-        . $network->last()->as_string() . ')';
+    return $self->_labels()->{$node_num} //= sprintf(
+        'Node %d - %s (%s - %s)',
+        $node_num,
+        $network->as_string,
+        $network->first()->as_string,
+        $network->last()->as_string,
+    );
 }
 
 sub _data_record_representation {
